@@ -463,6 +463,24 @@ class Graph:
 
         return txtout
 
+    def get_py_file(self):
+        txtout = ""
+
+        lookup_table = self.get_lookup_table()
+        cell_names, edges, _ = self.get_all_cells_edges()
+        cells = [self.get_cell(cn) for cn in cell_names]
+
+        for c in cells:
+            txtout += "# <" + c.name + ">\n"
+            if c.content_type == "python":
+                txtout += c.content + "\n"
+            else:
+                txtout += "\"\"\"\n" + c.content + "\n\"\"\"\n"
+
+        txtout += "# <EOF>"
+
+        return txtout
+
 
 class Interpreter:
 
@@ -1153,4 +1171,9 @@ def create_app(test_config=None):
 
         return "true"
 
+    @app.route("/get_py_text/", methods=["POST"])
+    def get_py_text():
+        py_txt = interpreter.graph.get_py_file()
+        return py_txt
+
     return app
